@@ -53,5 +53,7 @@ SEXP R_zmq_poll(SEXP R_socket, SEXP R_type, SEXP R_timeout);
 SEXP R_zmq_poll_free();
 SEXP R_zmq_poll_length();
 SEXP R_zmq_poll_get_revents(SEXP R_index);
+SEXP R_zmq_poll2(SEXP R_socket, SEXP R_type, SEXP R_timeout);
+SEXP R_zmq_poll2_get_revents(SEXP R_index, SEXP R_pollitem);
 
 #endif
